@@ -1,6 +1,7 @@
-import re
 import abc
+import re
 
+from metar_taf_parser.commons.converter import convert_temperature_remarks, convert_precipitation_amount
 from metar_taf_parser.commons.exception import TranslationError
 from metar_taf_parser.commons.i18n import _
 
@@ -12,7 +13,7 @@ def empty_if_none(code: str) -> str:
 class Command(abc.ABC):
 
     @abc.abstractmethod
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         pass
 
     @abc.abstractmethod
@@ -21,7 +22,7 @@ class Command(abc.ABC):
 
 
 class CeilingHeightCommand(Command):
-    regex = r'^CIG (\d{3})V(\d{3})'
+    regex = r'^CIG (\d{3})V(\d{3})\b'
 
     def __init__(self):
         self._pattern = re.compile(CeilingHeightCommand.regex)
@@ -29,16 +30,16 @@ class CeilingHeightCommand(Command):
     def can_parse(self, code: str) -> any:
         return self._pattern.match(code)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         min_ceiling = int(matches[0]) * 100
         max_ceiling = int(matches[1]) * 100
-        remark.append(_("Remark.Ceiling.Height").format(min_ceiling, max_ceiling))
+        remark.append(_('Remark.Ceiling.Height').format(min_ceiling, max_ceiling))
         return self._pattern.sub('', code, 1), remark
 
 
 class CeilingSecondLocationCommand(Command):
-    regex = r'^CIG (\d{3}) (\w+)'
+    regex = r'^CIG (\d{3}) (\w+)\b'
 
     def __init__(self):
         self._pattern = re.compile(CeilingSecondLocationCommand.regex)
@@ -46,7 +47,7 @@ class CeilingSecondLocationCommand(Command):
     def can_parse(self, code: str) -> any:
         return self._pattern.match(code)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         height = 100 * int(matches[0])
         remark.append(_('Remark.Ceiling.Second.Location').format(height, matches[1]))
@@ -62,19 +63,155 @@ class HailSizeCommand(Command):
     def can_parse(self, code: str) -> any:
         return self._pattern.match(code)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Hail').format(matches[0]))
         return self._pattern.sub('', code, 1), remark
 
 
+class HourlyMaximumMinimumTemperatureCommand(Command):
+    regex = r'^4([01])(\d{3})([01])(\d{3})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(HourlyMaximumMinimumTemperatureCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Hourly.Maximum.Minimum.Temperature').format(
+            convert_temperature_remarks(matches[0], matches[1]),
+            convert_temperature_remarks(matches[2], matches[3])
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+
+class HourlyMaximumTemperatureCommand(Command):
+    regex = r'^1([01])(\d{3})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(HourlyMaximumTemperatureCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Hourly.Maximum.Temperature').format(
+            convert_temperature_remarks(matches[0], matches[1])
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+
+class HourlyMinimumTemperatureCommand(Command):
+    regex = r'^2([01])(\d{3})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(HourlyMinimumTemperatureCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Hourly.Minimum.Temperature').format(
+            convert_temperature_remarks(matches[0], matches[1])
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+
+class HourlyPrecipitationAmountCommand(Command):
+    regex = r'^P(\d{4})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(HourlyPrecipitationAmountCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Precipitation.Amount.Hourly').format(
+            int(matches[0])
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+
+class HourlyPressureCommand(Command):
+    regex = r'^5(\d)(\d{3})\b'
+
+    barometer_tendency = {
+        0: 'Remark.Barometer.0',
+        1: 'Remark.Barometer.1',
+        2: 'Remark.Barometer.2',
+        3: 'Remark.Barometer.3',
+        4: 'Remark.Barometer.4',
+        5: 'Remark.Barometer.5',
+        6: 'Remark.Barometer.6',
+        7: 'Remark.Barometer.7',
+        8: 'Remark.Barometer.8'
+    }
+
+    def __init__(self):
+        self._pattern = re.compile(HourlyPressureCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(
+            _(HourlyPressureCommand.barometer_tendency[int(matches[0])])
+            + ' '
+            + _('Remark.Pressure.Tendency').format(float(matches[1]) / 10)
+        )
+        return self._pattern.sub('', code, 1), remark
+
+
+class HourlyTemperatureDewPointCommand(Command):
+    regex = r'^T([01])(\d{3})(([01])(\d{3}))?'
+
+    def __init__(self):
+        self._pattern = re.compile(HourlyTemperatureDewPointCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        if matches[2] is None:
+            remark.append(_('Remark.Hourly.Temperature').format(convert_temperature_remarks(matches[0], matches[1])))
+        else:
+            remark.append(_('Remark.Hourly.Temperature.Dew.Point').format(
+                convert_temperature_remarks(matches[0], matches[1]),
+                convert_temperature_remarks(matches[3], matches[4])
+            ))
+        return self._pattern.sub('', code, 1), remark
+
+
+class IceAccretionCommand(Command):
+    regex = r'^l(\d)(\d{3})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(IceAccretionCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Ice.Accretion.Amount').format(int(matches[1]), int(matches[0])))
+        return self._pattern.sub('', code, 1), remark
+
+
 class ObscurationCommand(Command):
     regex = r'^([A-Z]{2}) ([A-Z]{3})(\d{3})'
 
     def __init__(self):
         self._pattern = re.compile(ObscurationCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         layer = _('CloudQuantity.' + matches[1])
         height = 100 * int(matches[2])
@@ -86,13 +223,65 @@ class ObscurationCommand(Command):
         return self._pattern.match(code)
 
 
+class PrecipitationAmount24HourCommand(Command):
+    regex = r'^7(\d{4})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(PrecipitationAmount24HourCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Precipitation.Amount.24').format(convert_precipitation_amount(matches[0])))
+        return self._pattern.sub('', code, 1), remark
+
+
+class PrecipitationAmount36HourCommand(Command):
+    regex = r'^([36])(\d{4})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(PrecipitationAmount36HourCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Precipitation.Amount.3.6').
+                      format(matches[0], convert_precipitation_amount(matches[1])))
+        return self._pattern.sub('', code, 1), remark
+
+
+class PrecipitationBegCommand(Command):
+    regex = r'^(([A-Z]{2})?([A-Z]{2})B(\d{2})?(\d{2}))'
+
+    def __init__(self) -> None:
+        super().__init__()
+        self._pattern = re.compile(PrecipitationBegCommand.regex)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Precipitation.Beg').format(
+            '' if matches[1] is None else _('Descriptive.' + matches[1]),
+            _('Phenomenon.' + matches[2]),
+            empty_if_none(matches[3]),
+            matches[4]
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+
 class PrecipitationBegEndCommand(Command):
     regex = r'^(([A-Z]{2})?([A-Z]{2})B(\d{2})?(\d{2})E(\d{2})?(\d{2}))'
 
     def __init__(self):
         self._pattern = re.compile(PrecipitationBegEndCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Precipitation.Beg.End').format(
             '' if matches[1] is None else _('Descriptive.' + matches[1]),
@@ -108,13 +297,33 @@ class PrecipitationBegEndCommand(Command):
         return self._pattern.match(code)
 
 
+class PrecipitationEndCommand(Command):
+    regex = r'^(([A-Z]{2})?([A-Z]{2})E(\d{2})?(\d{2}))'
+
+    def __init__(self):
+        self._pattern = re.compile(PrecipitationEndCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Precipitation.End').format(
+            '' if matches[1] is None else _('Descriptive.' + matches[1]),
+            _('Phenomenon.' + matches[2]),
+            empty_if_none(matches[3]),
+            matches[4]
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+
 class PrevailingVisibilityCommand(Command):
     regex = r'^VIS ((\d)*( )?(\d?/?\d))V((\d)*( )?(\d?/?\d))'
 
     def __init__(self):
         self._pattern = re.compile(PrevailingVisibilityCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Variable.Prevailing.Visibility').format(
             matches[0], matches[4])
@@ -131,7 +340,7 @@ class SeaLevelPressureCommand(Command):
     def __init__(self):
         self._pattern = re.compile(SeaLevelPressureCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         pressure = '9' if matches[0].startswith('9') else '10'
         pressure += matches[0] + '.' + matches[1]
@@ -148,7 +357,7 @@ class SecondLocationVisibilityCommand(Command):
     def __init__(self):
         self._pattern = re.compile(SecondLocationVisibilityCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Second.Location.Visibility').format(
             matches[0], matches[4])
@@ -165,7 +374,7 @@ class SectorVisibilityCommand(Command):
     def __init__(self):
         self._pattern = re.compile(SectorVisibilityCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Sector.Visibility').format(
             _('Converter.' + matches[0]),
@@ -183,7 +392,7 @@ class SmallHailSizeCommand(Command):
     def __init__(self):
         self._pattern = re.compile(SmallHailSizeCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Hail.LesserThan').format(matches[0]))
         return self._pattern.sub('', code, 1), remark
@@ -192,13 +401,28 @@ class SmallHailSizeCommand(Command):
         return self._pattern.match(code)
 
 
+class SnowDepthCommand(Command):
+    regex = r'^4/(\d{3})'
+
+    def __init__(self):
+        self._pattern = re.compile(SnowDepthCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Snow.Depth').format(int(matches[0])))
+        return self._pattern.sub('', code, 1), remark
+
+
 class SnowIncreaseCommand(Command):
     regex = r'^SNINCR (\d+)/(\d+)'
 
     def __init__(self):
         self._pattern = re.compile(SnowIncreaseCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Snow.Increasing.Rapidly').format(matches[0], matches[1]))
         return self._pattern.sub('', code, 1), remark
@@ -213,7 +437,7 @@ class SnowPelletsCommand(Command):
     def __init__(self):
         self._pattern = re.compile(SnowPelletsCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Snow.Pellets').format(_('Remark.' + matches[0])))
         return self._pattern.sub('', code, 1), remark
@@ -222,13 +446,28 @@ class SnowPelletsCommand(Command):
         return self._pattern.match(code)
 
 
+class SunshineDurationCommand(Command):
+    regex = r'^98(\d{3})'
+
+    def __init__(self):
+        self._pattern = re.compile(SunshineDurationCommand.regex)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Sunshine.Duration').format(int(matches[0])))
+        return self._pattern.sub('', code, 1), remark
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+
 class SurfaceVisibilityCommand(Command):
     regex = r'^SFC VIS ((\d)*( )?(\d?/?\d))'
 
     def __init__(self):
         self._pattern = re.compile(SurfaceVisibilityCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Surface.Visibility').format(matches[0]))
         return self._pattern.sub('', code, 1), remark
@@ -243,7 +482,7 @@ class ThunderStormLocationCommand(Command):
     def __init__(self):
         self._pattern = re.compile(ThunderStormLocationCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Thunderstorm.Location').format(_('Converter.' + matches[0])))
         return self._pattern.sub('', code, 1), remark
@@ -258,7 +497,7 @@ class ThunderStormLocationMovingCommand(Command):
     def __init__(self):
         self._pattern = re.compile(ThunderStormLocationMovingCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Thunderstorm.Location.Moving').format(
             _('Converter.' + matches[0]), _('Converter.' + matches[1])
@@ -275,7 +514,7 @@ class TornadicActivityBegCommand(Command):
     def __init__(self):
         self._pattern = re.compile(TornadicActivityBegCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Tornadic.Activity.Beginning').format(
             _('Remark.' + matches[0].replace(' ', '')),
@@ -296,7 +535,7 @@ class TornadicActivityBegEndCommand(Command):
     def __init__(self):
         self._pattern = re.compile(TornadicActivityBegEndCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Tornadic.Activity.BegEnd').format(
             _('Remark.' + matches[0].replace(' ', '')),
@@ -319,7 +558,7 @@ class TornadicActivityEndCommand(Command):
     def __init__(self):
         self._pattern = re.compile(TornadicActivityEndCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Tornadic.Activity.Ending').format(
             _('Remark.' + matches[0].replace(' ', '')),
@@ -340,7 +579,7 @@ class TowerVisibilityCommand(Command):
     def __init__(self):
         self._pattern = re.compile(TowerVisibilityCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Tower.Visibility').format(matches[0]))
         return self._pattern.sub('', code, 1), remark
@@ -355,7 +594,7 @@ class VariableSkyCommand(Command):
     def __init__(self):
         self._pattern = re.compile(VariableSkyCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Variable.Sky.Condition').format(
             _('CloudQuantity.' + matches[0]),
@@ -373,7 +612,7 @@ class VariableSkyHeightCommand(Command):
     def __init__(self):
         self._pattern = re.compile(VariableSkyHeightCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.Variable.Sky.Condition.Height').format(
             100 * int(matches[1]),
@@ -392,7 +631,7 @@ class VirgaDirectionCommand(Command):
     def __init__(self):
         self._pattern = re.compile(VirgaDirectionCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         match = self._pattern.search(code).groups()
         remark.append(_('Remark.Virga.Direction').format(_('Converter.' + match[0])))
         return self._pattern.sub('', code, 1), remark
@@ -401,13 +640,30 @@ class VirgaDirectionCommand(Command):
         return self._pattern.match(code)
 
 
+class WaterEquivalentSnowCommand(Command):
+    regex = r'^933(\d{3})\b'
+
+    def __init__(self):
+        self._pattern = re.compile(WaterEquivalentSnowCommand.regex)
+
+    def can_parse(self, code: str) -> any:
+        return self._pattern.match(code)
+
+    def execute(self, code: str, remark: list) -> tuple:
+        matches = self._pattern.search(code).groups()
+        remark.append(_('Remark.Water.Equivalent.Snow.Ground').format(
+            float(matches[0]) / 10
+        ))
+        return self._pattern.sub('', code, 1), remark
+
+
 class WindPeakCommand(Command):
     regex = r'^PK WND (\d{3})(\d{2,3})/(\d{2})?(\d{2})'
 
     def __init__(self):
         self._pattern = re.compile(WindPeakCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.PeakWind').format(
             matches[0],
@@ -427,7 +683,7 @@ class WindShiftCommand(Command):
     def __init__(self):
         self._pattern = re.compile(WindShiftCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.WindShift').format(
             empty_if_none(matches[0]),
@@ -445,7 +701,7 @@ class WindShiftFropaCommand(Command):
     def __init__(self):
         self._pattern = re.compile(WindShiftFropaCommand.regex)
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         matches = self._pattern.search(code).groups()
         remark.append(_('Remark.WindShift.FROPA').format(
             empty_if_none(matches[0]),
@@ -461,7 +717,7 @@ class DefaultCommand(Command):
     def can_parse(self, code: str) -> any:
         return True
 
-    def execute(self, code: str, remark: [str]) -> (str, [str]):
+    def execute(self, code: str, remark: list) -> tuple:
         rmk_split = code.split(' ', 1)
         try:
             rem = _('Remark.' + rmk_split[0])
@@ -487,6 +743,8 @@ class RemarkCommandSupplier:
                               TornadicActivityBegCommand(),
                               TornadicActivityEndCommand(),
                               PrecipitationBegEndCommand(),
+                              PrecipitationBegCommand(),
+                              PrecipitationEndCommand(),
                               ThunderStormLocationMovingCommand(),
                               ThunderStormLocationCommand(),
                               SmallHailSizeCommand(),
@@ -499,7 +757,20 @@ class RemarkCommandSupplier:
                               VariableSkyCommand(),
                               CeilingSecondLocationCommand(),
                               SeaLevelPressureCommand(),
-                              SnowIncreaseCommand()]
+                              SnowIncreaseCommand(),
+                              HourlyMaximumMinimumTemperatureCommand(),
+                              HourlyMaximumTemperatureCommand(),
+                              HourlyMinimumTemperatureCommand(),
+                              HourlyPrecipitationAmountCommand(),
+                              HourlyTemperatureDewPointCommand(),
+                              HourlyPressureCommand(),
+                              IceAccretionCommand(),
+                              PrecipitationAmount36HourCommand(),
+                              PrecipitationAmount24HourCommand(),
+                              SnowDepthCommand(),
+                              SunshineDurationCommand(),
+                              WaterEquivalentSnowCommand()
+                              ]
 
     def get(self, code: str) -> Command:
         for command in self._command_list:
